Package: MKmisc
Version: 2.0
Date: 2026-05-07
Title: Miscellaneous Functions from M. Kohl
Authors@R: person("Matthias", "Kohl", role = c("aut", "cre"),
                  email = "Matthias.Kohl@stamats.de", 
                  comment = c(ORCID = "0000-0001-9514-8910"))
Author: Matthias Kohl [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-9514-8910>)
Maintainer: Matthias Kohl <Matthias.Kohl@stamats.de>
Depends: R(>= 4.0.0)
Imports: stats, utils, graphics, grDevices, RColorBrewer, robustbase,
        ggplot2, scales, limma
Suggests: gplots, Amelia, knitr, rmarkdown, exactRankTests, foreach,
        parallel, doParallel
VignetteBuilder: knitr
Description: Contains several functions for statistical data analysis; e.g. for sample size and power calculations, computation of confidence intervals and tests, and generation of similarity matrices.
License: LGPL-3
URL: https://github.com/stamats/MKmisc
NeedsCompilation: no
Packaged: 2026-05-07 13:03:01 UTC; kohlm
Repository: CRAN
Date/Publication: 2026-05-07 15:51:32 UTC
Built: R 4.5.2; ; 2026-05-07 16:33:42 UTC; unix
