import("stats", "ggplot2")
importFrom("utils", "combn")
importFrom("graphics", "layout", "image", "axis", "box", "par")
importFrom("grDevices", "colorRampPalette")
importFrom("robustbase", "covMcd", "covOGK")
importFrom("RColorBrewer", "brewer.pal")
importFrom("scales", "trans_new")
importFrom("limma", "lmFit", "makeContrasts", "contrasts.fit", "eBayes",
           "topTable")
export(simCorVars,
       glog,
       glog10,
       glog2,
       inv.glog,
       inv.glog10,
       inv.glog2,
       scale_y_glog,
       scale_x_glog,
       scale_y_glog10,
       scale_x_glog10,
       scale_y_glog2,
       scale_x_glog2,
       scale_y_neglog,
       scale_x_neglog,
       scale_y_neglog10,
       scale_x_neglog10,
       scale_y_neglog2,
       scale_x_neglog2,
       optCutoff,
       melt.long,
       mi.t.test,
       imputeSD,
       ssize.pcc,
       predValues,
       perfMeasures,
       perfScores,
       quantileCI,
       medianCI,
       madCI,
       normCI,
       normDiffCI,
       hsu.t.test,
       mod.t.test,
       mod.oneway.test,
       pairwise.mod.t.test,
       power.diagnostic.test,
       power.nb.test,
       power.welch.t.test,
       power.hsu.t.test,
       AUC,
       AUC.test,
       binomCI,
       corDist,
       stringDist,
       stringSim,
       traceBack,
       corPlot,
       fiveNS,
       heatmapCol,
       HLgof.test,
       IQrange,
       sIQR,
       meanAD,
       CV,
       cvCI,
       medCV,
       iqrCV,
       SNR,
       medSNR,
       iqrSNR,
       madMatrix,
       madPlot,
       simPlot,
       oneWayAnova,
       or2rr,
       risks,
       rrCI,
       pairwise.auc,
       pairwise.fc,
       pairwise.logfc,
       pairwise.fun,
       qbxp.stats,
       qboxplot,
       repMeans,
       thyroid,
       twoWayAnova)

S3method(qboxplot, default)
S3method(qboxplot, formula)
S3method(hsu.t.test, default)
S3method(hsu.t.test, formula)
S3method(mi.t.test, default)
S3method(print, confint)
